%define upstream_name    Razor2-Client-Agent
%define upstream_version 2.86

# Filter the Perl extension module
%{?perl_default_filter}

Name:       perl-Razor-Agent
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 11
Summary:    Use a Razor catalogue server to filter spam messages
Group:      Networking/Mail
License:    Artistic License 2.0
Url:        https://razor.sourceforge.net/
Source0:    https://prdownloads.sourceforge.net/razor/%{upstream_name}-%{upstream_version}.tar.gz
Patch2:		perl-Razor-Agent-2.85-parallel-make.patch

BuildRequires: perl(Digest::SHA1)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Copy)
BuildRequires: perl(File::Spec)
BuildRequires: perl(Getopt::Long)
BuildRequires: perl(MIME::Base64)
BuildRequires: perl(Test::More)
BuildRequires: perl(Time::HiRes)
BuildRequires: perl(URI::Escape)
BuildRequires: perl-devel
BuildRequires: perl(Net::DNS)
BuildRequires: perl-MailTools
Requires:   perl-Net-DNS
Requires(post):   netcat-traditional

%description
Vipul's Razor is a distributed, collaborative, spam detection and filtering
network. Razor establishes a distributed and constantly updating catalogue
of spam in propagation.  This catalogue is used by clients to filter out
known spam. On receiving a spam, a Razor Reporting Agent (run by an
end-user or a troll box) calculates and submits a 20-character unique
identification of the spam (a SHA Digest) to its closest Razor Catalogue
Server. The Catalogue Server echos this signature to other trusted servers
after storing it in its database.  Prior to manual processing or
transport-level reception, Razor Filtering Agents (end-users and MTAs)
check their incoming mail against a Catalogue Server and filter out or deny
transport in case of a signature match. Catalogued spam, once identified
and reported by a Reporting Agent, can be blocked out by the rest of the
Filtering Agents on the network.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
%autopatch -p0

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor

%make_build CFLAGS="%{optflags}" 

%check
make test

%install
%make_install

install -d %{buildroot}%{_mandir}/man5
install -m0644 blib/man5/*.5 %{buildroot}%{_mandir}/man5

# fix some defaults
install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -d %{buildroot}/var/log/razor
install -d %{buildroot}%{_sysconfdir}/razor

cat > %{buildroot}%{_sysconfdir}/razor/razor-agent.conf << EOF
logfile                = /var/log/razor/razor-agent.log
EOF

# fix logrotating
cat > %{buildroot}%{_sysconfdir}/logrotate.d/razor-agent << EOF
/var/log/razor/razor-agent.log {
    # create 644 root root
    weekly
    notifempty
    missingok
    compress
}
EOF

%post
# only do this if we have a working network and if the config file contains just one line
if [ "`cat %{_sysconfdir}/razor/razor-agent.conf|wc -l`" -eq "1" ] ; then
    if echo | nc -w1 discovery.razor.cloudmark.com 2703 >/dev/null 2>&1; then
        %{_bindir}/razor-admin -d -create -home=%{_sysconfdir}/razor
    else
        echo "You might want to run \"%{_bindir}/razor-admin -d -create -home=%{_sysconfdir}/razor\" when your network works"
    fi
fi

%files
%doc BUGS CREDITS Changes FAQ INSTALL LICENSE META.yml MYMETA.yml README.md
%dir %{_sysconfdir}/razor
%config(noreplace) %{_sysconfdir}/razor/razor-agent.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/razor-agent
%{_bindir}/*
%{_mandir}/*/*
%{perl_vendorarch}/Razor2
%{perl_vendorarch}/auto/Razor2
%{_logdir}/razor


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 2.860.0-11.mga10
+ Revision: 2226667
- Mageia 10 Mass Rebuild

* Fri Aug 23 2024 tv <tv> 2.860.0-10.mga10
+ Revision: 2089263
- Rebuild for perl-5.40

* Thu Nov 30 2023 tv <tv> 2.860.0-9.mga10
+ Revision: 2011609
- Rebuild for perl-5.38

* Tue Jun 07 2022 umeabot <umeabot> 2.860.0-8.mga9
+ Revision: 1862332
- Rebuild for Perl 5.36

* Thu Mar 17 2022 umeabot <umeabot> 2.860.0-7.mga9
+ Revision: 1796018
- Mageia 9 Mass Rebuild

* Mon May 24 2021 umeabot <umeabot> 2.860.0-6.mga9
+ Revision: 1727049
- Rebuild for perl 5.34

* Wed Jun 17 2020 umeabot <umeabot> 2.860.0-5.mga8
+ Revision: 1595149
- Rebuild for perl 5.32

* Sun Feb 16 2020 umeabot <umeabot> 2.860.0-4.mga8
+ Revision: 1530091
- Mageia 8 Mass Rebuild

* Tue Aug 27 2019 tmb <tmb> 2.860.0-3.mga8
+ Revision: 1433885
- rebuild for perl 5.30

* Tue Aug 27 2019 tv <tv> 2.860.0-2.mga8
+ Revision: 1433282
- rebuild with perl-5.30

* Sun Aug 11 2019 tv <tv> 2.860.0-1.mga8
+ Revision: 1428678
- update to 2.86

* Fri Sep 21 2018 umeabot <umeabot> 2.850.0-25.mga7
+ Revision: 1293735
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 guillomovitch <guillomovitch> 2.850.0-24.mga7
+ Revision: 1249766
- rebuild for perl 5.28

* Tue Oct 03 2017 tv <tv> 2.850.0-23.mga7
+ Revision: 1166395
- rebuild with fixed rpm for missing autodeps

* Thu Sep 28 2017 tv <tv> 2.850.0-22.mga7
+ Revision: 1160820
- patch 2: fix parralel build

* Tue Sep 05 2017 pterjan <pterjan> 2.850.0-21.mga7
+ Revision: 1151497
- Do not block forever when failing to contact discovery.razor.cloudmark.com

* Thu Aug 31 2017 pterjan <pterjan> 2.850.0-20.mga7
+ Revision: 1149921
- Rebuild for perl ABI changes

* Mon Jul 24 2017 tv <tv> 2.850.0-19.mga7
+ Revision: 1129825
- rebuild for perl 5.26
+ neoclust <neoclust>
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 2.850.0-17.mga6
+ Revision: 1032716
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 2.850.0-16.mga6
+ Revision: 957937
- Mageia 6 Mass Rebuild

* Fri Jun 26 2015 tv <tv> 2.850.0-15.mga6
+ Revision: 845191
- rebuild for soname-ifed perl

* Tue Jun 23 2015 shlomif <shlomif> 2.850.0-14.mga6
+ Revision: 840951
- Rebuild for the new perl

* Wed Oct 15 2014 umeabot <umeabot> 2.850.0-13.mga5
+ Revision: 750986
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 2.850.0-12.mga5
+ Revision: 732522
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 2.850.0-11.mga5
+ Revision: 686087
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 jquelin <jquelin> 2.850.0-10.mga5
+ Revision: 632314
- perl 5.20.0 rebuild

* Thu Apr 10 2014 spuhler <spuhler> 2.850.0-9.mga5
+ Revision: 613296
- changed Requires: hping2 to Requires(post): hping3
  * hping2 was obsoleted by hping3

* Sat Oct 19 2013 umeabot <umeabot> 2.850.0-9.mga4
+ Revision: 525575
- Mageia 4 Mass Rebuild

* Fri May 31 2013 jquelin <jquelin> 2.850.0-8.mga4
+ Revision: 433703
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 2.85-7.mga3
+ Revision: 372225
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed May 30 2012 jquelin <jquelin> 2.85-6.mga3
+ Revision: 251088
- rebuild for perl 5.16

* Sun Jun 12 2011 sander85 <sander85> 2.85-5.mga2
+ Revision: 104932
- Rebuild for perl 5.14

* Sun Jan 23 2011 jquelin <jquelin> 2.85-4.mga1
+ Revision: 34202
- mageia rebuild
- imported package perl-Razor-Agent


* Sun Aug 01 2010 Funda Wang <fwang@mandriva.org> 2.85-4mdv2011.0
+ Revision: 564577
- rebuild for perl 5.12.1

  + Jérôme Quelin <jquelin@mandriva.org>
    - rebuild for perl 5.12

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 2.85-2mdv2010.1
+ Revision: 426586
- rebuild

* Wed Jul 23 2008 Frederic Crozat <fcrozat@mandriva.com> 2.85-1mdv2009.0
+ Revision: 242355
- Release 2.85
- Code is now under Artistic License 2.0

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 2.84-5mdv2009.0
+ Revision: 224004
- rebuild

* Wed Jan 23 2008 Thierry Vignaud <tv@mandriva.org> 2.84-4mdv2008.1
+ Revision: 157265
- rebuild with fixed %%serverbuild macro

* Tue Jan 15 2008 Thierry Vignaud <tv@mandriva.org> 2.84-3mdv2008.1
+ Revision: 152251
- rebuild
- kill re-definition of %%buildroot on Pixel's request
- replace %%{_datadir}/man by %%{_mandir}!

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Wed Jul 18 2007 Oden Eriksson <oeriksson@mandriva.com> 2.84-2mdv2008.0
+ Revision: 53257
- provide a basic /etc/razor/razor-agent.conf file and do magic in %%post, fixes #26573
- use the %%serverbuild macro

* Sun Jun 03 2007 Oden Eriksson <oeriksson@mandriva.com> 2.84-1mdv2008.0
+ Revision: 34849
- 2.84
- spec file cleansing


* Wed May 31 2006 Frederic Crozat <fcrozat@mandriva.com> 2.82-1mdv2007.0
- Release 2.82

* Tue Apr 04 2006 Frederic Crozat <fcrozat@mandriva.com> 2.81-1mdk
- Release 2.80
- use mkrel

* Wed Mar 01 2006 Frederic Crozat <fcrozat@mandriva.com> 2.80-1mdk
- Release 2.80

* Thu Jul 07 2005 Frederic Crozat <fcrozat@mandriva.com> 2.75-1mdk 
- Release 2.75

* Mon Jul 04 2005 Frederic Crozat <fcrozat@mandriva.com> 2.74-1mdk 
- Release 2.74

* Tue Jun 21 2005 Götz Waschk <waschk@mandriva.org> 2.72-2mdk
- drop the symlinks (thanks to Daniel J McDonald)

* Fri Jun 17 2005 Götz Waschk <waschk@mandriva.org> 2.72-1mdk
- New release 2.72

* Wed Dec 29 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.67-1mdk 
- Release 2.67

* Mon Nov 15 2004 Michael Scherer <misc@mandrake.org> 2.61-2mdk
- Rebuild for new perl

* Tue Jul 06 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.61-1mdk
- Release 2.61

* Wed May 19 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.40-1mdk
- Release 2.40
- Remove patch0 (merged upstream)
- perl-Digest-Nilsimsa is no longer needed

* Mon Nov 17 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.36-3mdk
- rebuilt for perl-5.8.2

* Wed Nov 05 2003 Frederic Crozat <fcrozat@mandrakesoft.com> 2.36-2mdk
- Fix build on older distro than 9.2 (Nicolas Chipaux)
- from Oden Eriksson <oden.eriksson@kvikkjokk.net>
 - added rediffed P0 taken from the spamassassin v2.60 tarball
 - misc spec file fixes

* Mon Aug 18 2003 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.36-1mdk
- 2.36
- use %%makeinstall_std macro

* Thu Jul 31 2003 Frederic Crozat <fcrozat@mandrakesoft.com> - 2.34-4mdk
- Always enforce perl-Net-DNS dependency, it is not auto-detected by spechelper

* Wed Jul 16 2003 Frederic Crozat <fcrozat@mandrakesoft.com> - 2.34-3mdk
- Fix buildrequires

* Wed Jun 04 2003 Frederic Crozat <fcrozat@mandrakesoft.com> - 2.34-2mdk
- Fix man install for Mdk 8.0

* Mon Jun 02 2003 Frederic Crozat <fcrozat@mandrakesoft.com> - 2.34-1mdk
- Release 2.34

